<!--
 Copyright (c) 2022 CESNET

 This software is released under the MIT License.
 https://opensource.org/licenses/MIT
-->

# Contributing

Contributions are welcome, and they are greatly appreciated! Every
little bit helps, and credit will always be given.

## Types of Contributions

### Report Bugs

Report bugs at <https://github.com/oarepo/oarepo-communities/issues>.

If you are reporting a bug, please include:

-   Your operating system name and version.
-   Any details about your local setup that might be helpful in troubleshooting.
-   Detailed steps to reproduce the bug.

### Fix Bugs

Look through the GitHub issues for bugs. Anything tagged with "bug"
is open to whoever wants to implement it.

### Implement Features

Look through the GitHub issues for features. Anything tagged with "feature"
is open to whoever wants to implement it.

### Write Documentation

OARepo-Communities could always use more documentation, whether as part of the
official OARepo-Communities docs, in docstrings, or even on the web in blog posts,
articles, and such.

### Submit Feedback

The best way to send feedback is to file an issue at
<https://github.com/oarepo/oarepo-communities/issues>.

If you are proposing a feature:

-   Explain in detail how it would work.
-   Keep the scope as narrow as possible, to make it easier to implement.
-   Remember that this is a volunteer-driven project, and that contributions
    are welcome :)

## Get Started

Ready to contribute? Here's how to set up `oarepo-communities` for local development.

1. Fork the `oarepo-communities` repo on GitHub.
2. Clone your fork locally:

    ```shell
    git clone git@github.com:your_name_here/oarepo-communities.git
    ```

3. Install your local copy into a virtualenv. This is how you set up your fork for local development:

    ```shell
    cd oarepo-communities
    python3 -m venv .venv && source .venv/bin/activate
    pip install -e .[all]
    pip install -r requirements-devel.txt
    ```

4. Create a branch for local development:

    ```shell
    git checkout -b name-of-your-bugfix-or-feature
    ```

5. Now you can make your changes locally.

6. When you're done making changes, check that your changes pass tests:

    ```shell
    ./run-tests.sh
    ```

    The tests will provide you with test coverage and also check PEP8 (code style), PEP257 (documentation), flake8 as well as build the Sphinx documentation and run doctests.

7. Commit your changes and push your branch to GitHub:

    ```shell
    git add .
    git commit -s -m "Your detailed description of your changes."
    git push origin name-of-your-bugfix-or-feature
    ```

8. Submit a pull request through the GitHub website.

## Pull Request Guidelines

Before you submit a pull request, check that it meets these guidelines:

1. The pull request should include tests and must not decrease test coverage.
2. If the pull request adds functionality, the docs should be updated. Put
   your new functionality into a function with a docstring.
3. The pull request should work for Python >=3.9.
